The latest version of the Python implementation of the AEA Framework:

<a href="https://img.shields.io/pypi/v/aea" target="_blank"><img alt="PyPI" src="https://img.shields.io/pypi/v/aea" /></a>. 

The framework is under rapid development with frequent breaking changes in the run-up to version `1.0` which is due in Q1 2021.

If you are upgrading your AEA project from a previous version of the AEA framework, please check out <a href="../upgrading/">the upgrading guide</a>.

The AEA framework's implementation in Python is in principle compatible with its implementation in any other language. The <a href="../language-agnostic-definition/">language agnostic definitions</a> describe the aspects of the framework an implementation must adhere to in order for their AEAs to be able to interact with AEAs built with other implementations of the framework.
